@@ -4,6 +4,6 @@ print `sparrow project create foo100`;
 use Sparrow::Constants;
 
 -d sparrow_root."/projects/foo100" and print "directory projects/foo100 exists\n";
--d sparrow_root."/projects/foo100/checkpoints" and print "directory projects/foo100/checkpoints exists\n";
+-d sparrow_root."/projects/foo100/tasks" and print "directory projects/foo100/tasks exists\n";
 
 
